# Development Notes

This document shows you how to setup `ragas_experimental` for development and how to 
perform some common tasks.

## Installation for Development

You can do an editable install of `ragas_experimental` by running the following command
```bash
# from src/experimental
poetry install
```


